package qq;

use strict;
use warnings;

our $VERSION = '0.06';

1;
__END__

=head1 NAME

qq - command line journal app

=head1 SYNOPSIS

  $> qq

=head1 DESCRIPTION

Type 'qq' at the command line to start the application

=head1 AUTHOR

Rajkumar Reddy

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2022 by Rajkumar Reddy. All rights reserved.

Open Source.


=cut
